@@ -13,15 +13,12 @@ should be a list.
 But note that FCompiler.executables is actually a dictionary of commands.
 
 """
-from __future__ import division, absolute_import, print_function
-
 __all__ = ['FCompiler', 'new_fcompiler', 'show_fcompilers',
            'dummy_fortran_file']
 
 import os
 import sys
 import re
-import types
 
 from numpy.compat import open_latin1
 
@@ -36,7 +33,6 @@ from numpy.distutils import log
 from numpy.distutils.misc_util import is_string, all_strings, is_sequence, \
     make_temp_file, get_shared_lib_extension
 from numpy.distutils.exec_command import find_executable
-from numpy.distutils.compat import get_exception
 from numpy.distutils import _shell_utils
 
 from .environment import EnvironmentConfig
@@ -362,7 +358,7 @@ class FCompiler(CCompiler):
         set_exe('archiver')
         set_exe('ranlib')
 
-    def update_executables(elf):
+    def update_executables(self):
         """Called at the beginning of customisation. Subclasses should
         override this if they need to set up the executables dictionary.
 
@@ -484,11 +480,11 @@ class FCompiler(CCompiler):
         # XXX Assuming that free format is default for f90 compiler.
         fix = self.command_vars.compiler_fix
         # NOTE: this and similar examples are probably just
-        # exluding --coverage flag when F90 = gfortran --coverage
+        # excluding --coverage flag when F90 = gfortran --coverage
         # instead of putting that flag somewhere more appropriate
         # this and similar examples where a Fortran compiler
         # environment variable has been customized by CI or a user
-        # should perhaps eventually be more throughly tested and more
+        # should perhaps eventually be more thoroughly tested and more
         # robustly handled
         if fix:
             fix = _shell_utils.NativeParser.split(fix)
@@ -614,8 +610,8 @@ class FCompiler(CCompiler):
                               src)
         try:
             self.spawn(command, display=display)
-        except DistutilsExecError:
-            msg = str(get_exception())
+        except DistutilsExecError as e:
+            msg = str(e)
             raise CompileError(msg)
 
     def module_options(self, module_dirs, module_build_dir):
@@ -682,8 +678,8 @@ class FCompiler(CCompiler):
             command = linker + ld_args
             try:
                 self.spawn(command)
-            except DistutilsExecError:
-                msg = str(get_exception())
+            except DistutilsExecError as e:
+                msg = str(e)
                 raise LinkError(msg)
         else:
             log.debug("skipping %s (up-to-date)", output_filename)
@@ -931,8 +927,7 @@ def show_fcompilers(dist=None):
             c = new_fcompiler(compiler=compiler, verbose=dist.verbose)
             c.customize(dist)
             v = c.get_version()
-        except (DistutilsModuleError, CompilerNotFound):
-            e = get_exception()
+        except (DistutilsModuleError, CompilerNotFound) as e:
             log.debug("show_fcompilers: %s not found" % (compiler,))
             log.debug(repr(e))
 
